#
# spec file for package cluster-glue
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define gid 90
%define uid 90
%define gname haclient
%define uname hacluster
# Directory where we install documentation
%global glue_docdir %{_defaultdocdir}/%{name}
Name:           cluster-glue
Version:        1.0.12+v1.git.1511436818.71ae59fa
Release:        169.1
Summary:        Reusable cluster components
License:        GPL-2.0 AND LGPL-2.1+
Group:          Productivity/Clustering/HA
Url:            https://github.com/ClusterLabs/cluster-glue.git
Source:         %{name}-%{version}.tar.bz2
Source2:        baselibs.conf
Source3:        hb_report.in
# PATCH-FIX-OPENSUSE: load libplumb symbols manually (thanks to lge) (bnc#694243)
Patch1:         bug-694243_cluster-glue_symbol-conflict.patch
# PATCH-FIX-OPENSUSE: drop lrm as it's not used anymore by pacemaker
Patch4:         cluster-glue_droplrm.patch
# PATCH-FIX-UPSTREAM: fix warnings seen by GCC7
# PATCH-FIX-OPENSUSE: Port scripts to Python 3
Patch5:         0001-Port-scripts-to-Python-3.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  e2fsprogs-devel
BuildRequires:  help2man
BuildRequires:  libaio-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  net-snmp-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(OpenIPMI)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       perl-TimeDate
Requires:       sudo
Requires(pre):  shadow
# The following is necessary since sbd is dropped from
# cluster-glue itself:
Recommends:     sbd
Conflicts:      heartbeat-common < 3.0.2
Conflicts:      pacemaker < 1.1.8
Obsoletes:      heartbeat-common < 3.0.2
%{?systemd_requires}
%if 0%{?suse_version} >= 1330
Requires(pre):  group(nobody)
Requires(pre):  user(nobody)
%endif

%description
A collection of common tools that are useful for writing cluster managers
such as Pacemaker.
Provides a local resource manager that understands the OCF and LSB
standards, and an interface to common STONITH devices.

%package -n libglue2
Summary:        Reusable cluster libraries
Group:          Productivity/Clustering/HA
Requires:       %{name} = %{version}-%{release}
Conflicts:      libheartbeat2 < 3.0.2
Obsoletes:      libheartbeat2 < 3.0.2

%description -n libglue2
A collection of libraries that are useful for writing cluster managers
such as Pacemaker.

%package -n libglue-devel
Summary:        Headers and libraries for writing cluster managers
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Requires:       libglue2 = %{version}-%{release}
Conflicts:      libheartbeat-devel < 3.0.2
Obsoletes:      libheartbeat-devel < 3.0.2

%description -n libglue-devel
Headers and shared libraries for a useful for writing cluster managers
such as Pacemaker.

%prep
%setup -q
%patch1 -p1
%patch4 -p1
%patch5 -p1

%build
export CFLAGS="${CFLAGS} %{optflags}"
export PYTHON="%{_bindir}/python3"
./autogen.sh
find . -type f -exec perl -pi -e 'BEGIN{undef $/};s[^#\!%{_bindir}/env perl][#\!%{_bindir}/perl]' {} \;
%configure \
    --disable-static \
    --enable-ipmilan=no \
    --enable-libnet=no \
    --disable-fatal-warnings \
    --with-package-name=%{name} \
    --with-daemon-group=%{gname} \
    --with-daemon-user=%{uname} \
    --with-systemdsystemunitdir=%{_unitdir} \
    --with-rundir=%{_rundir} \
    --docdir=%{glue_docdir}
make %{?_smp_mflags}

%install
%make_install
# Dont package static libs or compiled python
find %{buildroot} -type f "(" -name "*.la" -o -name "*.pyc" -o -name "*.pyo" ")" -delete -print
install -D -m 755 %{SOURCE3} %{buildroot}%{_sbindir}/hb_report
%if %{defined _unitdir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rclogd
%endif

%pre
getent group %{gname} >/dev/null || groupadd -r -g %{gid} %{gname} 
getent passwd %{uname} >/dev/null || useradd -r -u %{uid} -g %{gname} -d %{_localstatedir}/lib/heartbeat/cores/%{uname} -s /sbin/nologin -c "heartbeat processes" %{uname}
%service_add_pre logd.service

%post
%service_add_post logd.service

%preun
%service_del_preun logd.service

%postun
%service_del_postun logd.service

%post -n libglue2 -p /sbin/ldconfig
%postun -n libglue2 -p /sbin/ldconfig

%files
%{_defaultdocdir}/%{name}/
%dir %{_libdir}/heartbeat
%dir %{_var}/lib/heartbeat
%dir %{_var}/lib/heartbeat/cores
%dir %attr (0700, root, root) %{_var}/lib/heartbeat/cores/root
%dir %attr (0700, nobody, nobody) %{_var}/lib/heartbeat/cores/nobody
%dir %attr (0700, %{uname}, %{gname}) %{_var}/lib/heartbeat/cores/%{uname}
%dir %{_libdir}/heartbeat/plugins
%dir %{_libdir}/heartbeat/plugins/RAExec
%dir %{_libdir}/heartbeat/plugins/InterfaceMgr
%dir %{_libdir}/heartbeat/plugins/compress
%dir %{_libdir}/stonith
%dir %{_libdir}/stonith/plugins
%dir %{_libdir}/stonith/plugins/stonith2
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/ha_cf_support.sh
%{_datadir}/%{name}/openais_conf_support.sh
%{_datadir}/%{name}/utillib.sh
%{_datadir}/%{name}/ha_log.sh
%{_sbindir}/ha_logger
%{_sbindir}/hb_report
%{_sbindir}/cibsecret
%{_sbindir}/meatclient
%{_sbindir}/stonith
%{_unitdir}/logd.service
%{_mandir}/man1/*
%{_mandir}/man8/*
%doc AUTHORS
%doc COPYING
%doc logd/logd.cf
%{_sbindir}/rclogd
%{_libdir}/heartbeat/ha_logd
%{_libdir}/heartbeat/plugins/RAExec/*.so
%{_libdir}/heartbeat/plugins/InterfaceMgr/*.so
%{_libdir}/heartbeat/plugins/compress/*.so
%{_libdir}/stonith/plugins/external
%exclude %{_libdir}/stonith/plugins/stonith2/null.so
%exclude %{_libdir}/stonith/plugins/stonith2/ssh.so
%exclude %{_libdir}/stonith/plugins/external/ssh
%{_libdir}/stonith/plugins/stonith2/*.so
%{_libdir}/stonith/plugins/xen0-ha-dom0-stonith-helper

%files -n libglue2
%{_libdir}/lib*.so.*
%doc AUTHORS
%doc COPYING.LIB

%files -n libglue-devel
%dir %{_libdir}/heartbeat
%dir %{_libdir}/heartbeat/plugins
%dir %{_libdir}/heartbeat/plugins/test
%dir %{_datadir}/%{name}
%{_libdir}/lib*.so
%{_libdir}/heartbeat/ipctest
%{_libdir}/heartbeat/ipctransientclient
%{_libdir}/heartbeat/ipctransientserver
%{_libdir}/heartbeat/transient-test.sh
%{_libdir}/heartbeat/base64_md5_test
%{_libdir}/heartbeat/logtest
%{_includedir}/clplumbing
%{_includedir}/heartbeat
%exclude %{_includedir}/heartbeat/lrm
%{_includedir}/stonith
%{_includedir}/pils
%{_libdir}/heartbeat/plugins/test/test.so
%{_libdir}/stonith/plugins/stonith2/null.so
%{_libdir}/stonith/plugins/stonith2/ssh.so
%{_libdir}/stonith/plugins/external/ssh
%doc AUTHORS
%doc COPYING
%doc COPYING.LIB

%changelog
* Fri Feb  2 2018 ygao@suse.com
- spec: Still use 90 as the consistent gid for the group "haclient" among the cluster
* Thu Feb  1 2018 jengelh@inai.de
- Stop building static archives only to remove them later.
* Thu Jan 18 2018 tchvatal@suse.com
- Switch to pkgconfig dependencies
- Drop asciidoc from deps, even tho configure.ac checks for it
  the mans are generated by docbook
* Thu Jan 18 2018 tchvatal@suse.com
- Format with spec-cleaner
- Remove old distributions as we build only on SLE12+ (sle11/sle10)
- Always disable fatal warnings, it only turns on -Werror which is
  pointless for distro builds and just could break with gcc updates
- Use the user creation oneliner like other packages
* Mon Dec 18 2017 kgronlund@suse.com
- Fix Python 3 compatibility in these agents (bsc#1073376):
  * external/ibmrsa-telnet
  * external/dracmc-telnet
  * external/riloe
* Wed Nov 29 2017 kgronlund@suse.com
- Port scripts to Python 3
  * Add 0001-Port-scripts-to-Python-3.patch
* Thu Nov 23 2017 kgronlund@suse.com
- Update to version 1.0.12+v1.git.1511436818.71ae59fa:
  * Fix: stonith:external/ec2: Enforce en_US.UTF-8 locale when invoking aws client (bsc#1059171)
  * Drop libnet dependency (bsc#1069596)
* Wed Aug 23 2017 ygao@suse.com
- Update to version 1.0.12+v1.git.1501749673.bdd95fd0:
  * stonith: external/vcenter: Reset returns success with RESETPOWERON=0 if vm is already off (bsc#1050908)
  * Remove hb_report from doc/
  * Fix warnings reported by GCC7. (bsc#1030241)
  * * Drop 0001-Fix-warnings-reported-by-GCC7.patch which has been merged upstream
* Thu May 18 2017 mliska@suse.cz
- Remove openhpi support as the packages is going to be removed.
* Thu May 18 2017 mliska@suse.cz
- Add 0001-Fix-warnings-reported-by-GCC7.patch to fix bnc#1030241.
* Wed May  3 2017 kukuk@suse.de
- Require user and group nobody
* Thu Feb  9 2017 dimstar@opensuse.org
- Explicitly package %%{_docdir}/%%{name} to fix build with RPM 4.13.
* Wed Feb  1 2017 kgronlund@suse.com
- Update to version 1.0.12+v1.git.1485976882.03d61cd:
  * Low: ipc: fix poll function parameter type
  * Medium: hb_report: invoke crm to create a report
* Wed Nov  2 2016 kgronlund@suse.com
- Update to version 1.0.12+v1.git.1478088779.afaeeb2:
  * Low: stonith: Convert gethostbyname() usage to getaddrinfo()
  * Low: apcmastersnmp: Convert gethostbyname() usage to getaddrinfo()
  * Low: ipmilan_command: Convert gethostbyname() to getaddrinfo()
  * Low: wti_mpc: Convert gethostbyname() usage to getaddrinfo()
* Thu Oct 20 2016 kgronlund@suse.com
- Update to version 1.0.12+v1.git.1476869614.524e5d0:
  * Adjust version to correct sorting
* Tue Oct 18 2016 kgronlund@suse.com
- Update to version 1.0.12+git.1476707642.08bec62:
  * low: cl_plumbing: Fix incorrect negations
- Drop merged patches:
  * Remove cluster-glue-gcc5.patch
  * Remove remove-unused-constants.patch
* Tue Oct 11 2016 kgronlund@suse.com
- Update to version 1.0.12+git.1476172419.3e86358:
  * Upstream is now github.com/ClusterLabs/cluster-glue.git
  * stonith: describe -E option
* Mon May 23 2016 kgronlund@suse.com
- Update to 1.0.12+hg2818
  + Fix addresses of FSF, point to gnu.org/licenses instead
- Fix build with GCC 6
  + Add remove-unused-constants.patch
* Thu Feb  4 2016 kgronlund@suse.com
- Update to 1.0.12+hg2816
  + Medium: stonith: external/libvirt: fix handling of hosts with uppercase letters in names
- upstream cs: 56f40ec5d37e
* Fri Oct 16 2015 kgronlund@suse.com
- Update to 1.0.12+hg2815
  + Medium: stonith: external/ec2: use target's uname as default for port (bsc#947026)
- Replace hb_report with script which calls crm report (bsc#950182) (bsc#950483)
- Remove 0006-ec2-instance-tag-bsc-947026.patch
- Remove 0001-high-hb_report-Collect-logs-from-journald-boo-900654.patch
- Remove 0002-high-hb_report-Prefer-pacemaker.log-if-it-exists-bsc.patch
- Remove 0003-high-hb_report-Always-prefer-syslog-if-available-bsc.patch
- Remove 0004-low-hb_report-increase-time-to-wait-for-the-logmark.patch
- Remove 0005-low-hb_report-collect-libqb-version-bsc-943327.patch
- Remove bnc662816_cluster-glue_hb_report_abspath.patch
- Move libglue-devel to group Development/Libraries/C and C++
- Upstream cs: a10cd7cc13f5
* Fri Sep 25 2015 kgronlund@suse.com
- Dev: stonith: external/ec2: Be able to omit the "port" option. (bsc#947026) (fate#319008)
- Add 0006-ec2-instance-tag-bsc-947026.patch
* Wed Aug 26 2015 kgronlund@suse.com
- high: hb_report: Always prefer syslog if available (bsc#942906)
- low: hb_report: Increase time to wait for the logmark
- low: hb_report: Collect libqb version (bsc#943327)
- Add 0003-high-hb_report-Always-prefer-syslog-if-available-bsc.patch
- Add 0004-low-hb_report-increase-time-to-wait-for-the-logmark.patch
- Add 0005-low-hb_report-collect-libqb-version-bsc-943327.patch
* Fri Aug 14 2015 kgronlund@suse.com
- high: hb_report: Prefer pacemaker.log if it exists (bsc#941681)
- Add 0002-high-hb_report-Prefer-pacemaker.log-if-it-exists-bsc.patch
* Mon May 11 2015 kgronlund@suse.com
- Low: stonith: external/ec2: update name in the short description
- High: stonith: external/ec2: new agent for aws/ec2
- Medium: hb_report: use faster zypper interface if available
- Medium: stonith: external/vcenter: replace experimental smartmatch (bnc#900353)
- Medium: ha_logd: prevent race caused by pid reuse (bsc#894272)
- fix syslogmsgfmt logging inconsistency for stderr/stdout
- Medium: clplumbing: don't abort on bad input
- upstream cs: 9da0680bc9c0
* Tue Feb 24 2015 rguenther@suse.com
- Add cluster-glue-gcc5.patch to fix gazillions of -Wformat=2 warnings
  about signed/unsigned format vs. argument mismatches GCC 5 now emits.
  Fixes build with GCC 5.
* Wed Feb 18 2015 coolo@suse.com
- buildrequire the systemd macros before using them - and all
  the package wants is the macro anyway, so no need to buildrequire
  systemd libraries
* Wed Jan 21 2015 dmuhamedagic@suse.com
- undo: fix using hb_report script with non-bash shells due to
  bad logic
  * removed cluster-glue-fix-bashisms.patch
* Sat Dec 27 2014 Led <ledest@gmail.com>
- fix using hb_report script with non-bash shells
- add patches:
  + cluster-glue-fix-bashisms.patch
* Wed Nov 19 2014 dimstar@opensuse.org
- Replace systemd BuildRequires with pkgconfig(systemd): we do not
  require the full installation / dep chain of systemd.
* Fri Oct 10 2014 kgronlund@suse.com
- high: hb_report: Collect logs from journald (boo#900654)
- Add patch: 0001-high-hb_report-Collect-logs-from-journald-boo-900654.patch
* Thu Jul 17 2014 dmuhamedagic@suse.com
- hb_report: add -Q to usage
- upstream cs: ec7802482c73
* Wed Jul  9 2014 dmuhamedagic@suse.com
- hb_report: add -Q option for quick runs
- upstream cs: 51d0ebbb2868
* Wed Jul  2 2014 dmuhamedagic@suse.com
- hb_report: remove obsolete combine-logs.pl
- upstream cs: 0abe35bebf5f
* Wed Jun 25 2014 kgronlund@suse.com
- Medium: hb_report: dot is not illegal in file names (bnc#884079, debian#715391)
- upstream cs: 0f48479c251b
* Wed Jun 25 2014 kgronlund@suse.com
- Medium: hb_report: dot is not illegal in file names (bnc#884079, debian#715391)
- upstream cs: 0f48479c251b
* Thu Jun 12 2014 dmuhamedagic@suse.com
- hb_report: fix interface to gdb and zypper
- upstream cs: 45e21bc9795d
* Fri Jun  6 2014 dmuhamedagic@suse.com
- hb_report: update interface to zypper
- hb_report: support logs with varied timestamps
- upstream cs: b7d3393f5431
  * removed obsolete cluster-glue-configure-statedir.patch
* Tue May 20 2014 jsegitz@novell.com
- added service_add_pre to spec file
- removed .<CI_CNT>.<B_CNT> from the release tag
* Thu May  8 2014 ro@suse.de
- Add  cluster-glue-configure-statedir.patch
  * use _rundir macro and define GLUE_STATE_DIR accordingly
* Mon May  5 2014 kgronlund@suse.com
- Drop rc1 from release numbering (bnc#873456)
* Fri May  2 2014 dmuhamedagic@suse.com
- hb_report: fix ssh passwords for clusters larger than 2 (bnc#867365)
- upstream cs: b44fe9e0c67e
  * removed obsolete Low-hb_report-pcmk-lib-changed-permissions.patch (upstream)
  * removed obsolete 0001-hb_report-Don-t-use-deprecated-corosync-fplay-bnc-87.patch (upstream)
  * removed obsolete 0002-hb_report-Update-FSF-address-in-license.patch (upstream)
  * removed obsolete bnc863248-logd-add-systemd-support.patch (upstream)
  * removed obsolete bnc851990_cluster-glue_external_vcenter_disable_hostname_verification.patch (upstream)
  * removed obsolete bnc854060_hb_report-add-xz-support.patch (upstream)
  * removed obsolete ipmilan-ipmiif.patch (upstream)
* Fri Apr 11 2014 kgronlund@suse.com
- hb_report: pcmk lib changed permissions (bnc#872958)
- added patches:
  * Low-hb_report-pcmk-lib-changed-permissions.patch
* Mon Mar 31 2014 kgronlund@suse.com
- hb_report: Don't use deprecated corosync-fplay (bnc#870913)
- hb_report: Update FSF address in license
- added patches:
  * 0001-hb_report-Don-t-use-deprecated-corosync-fplay-bnc-87.patch
  * 0002-hb_report-Update-FSF-address-in-license.patch
* Sun Feb 23 2014 kgronlund@suse.com
- logd: Add systemd unit file for logd (bnc#863248)
- added patches:
  * bnc863248-logd-add-systemd-support.patch
* Tue Dec 10 2013 kgronlund@suse.com
- external/vcenter: Disable SSL hostname verification (bnc#851990)
* Mon Dec  9 2013 kgronlund@suse.com
- hb_report: Add support for xz compression (bnc#854060)
* Thu Oct 31 2013 dmuhamedagic@suse.com
- disable building ipmilan
- move the bladehpi stonith agent into a separate package
  (FATE#316529)
- enable fatal warnings
* Mon Oct 14 2013 kgronlund@suse.com
- add ipmilan-ipmiif.patch:
  Make sure to include OpenIPMI/ipmiif.h for correct
  version detection.
* Thu Oct  3 2013 dmuhamedagic@suse.com
- fix the tag glue-1.0.12-rc1
- since lrm bits are not compiled, this package conflicts with
  pacemaker < 1.1.8
* Thu Sep 26 2013 dmuhamedagic@suse.com
- clplumbing: increase listen backlog to 128
- upstream cs: 1.0.12-rc1
* Wed Sep 18 2013 lmb@suse.com
- Change to recommend sbd instead of requiring it to avoid dependency
  loop.
* Thu Aug 29 2013 dmuhamedagic@suse.com
- hb_report: fix test for the root user
- hb_report: add support for the rfc5424 syslog date format
- hb_report: add -X option for extra ssh options (fate#314906)
- hb_report: adjust for more pacemaker directories moving
- hb_report: Add "sudo" to package requirements (bnc#823087)
- stonith: external/libvirt: fix exit code in reset
- stonith: external/vcenter: do not list vms in status (bnc#825765)
- Fix gcc warning about wrong typecast on i586.
- fix various gcc warnings
- upstream cs: 8acfc748667a
* Mon May 13 2013 dmuhamedagic@suse.com
- stonith: fix memory leak in external.c
- stonith: use 0 for the unique parameters attribute in most
  agents
- upstream cs: 27019ba6670d
* Thu Mar 28 2013 dmuhamedagic@suse.com
- hb_report: ignore differences in white space
- upstream cs: 8347e8c9b94f
* Thu Mar 14 2013 dmuhamedagic@suse.com
- hb_report: enable ssh to prompt for passwords (bnc#808373)
- hb_report: do not assume that this is a loghost if the number
  of entries equals 1
- upstream cs: 3cff550e1084
* Mon Feb 25 2013 dmuhamedagic@suse.com
- hb_report: reduce severity of several info messages (bnc#804704)
- upstream cs: 0c0bd21916ce
* Mon Feb 11 2013 dmuhamedagic@suse.com
- hb_report: collect RA trace files
- hb_report: look for nodes in the archived CIB if pacemaker is
  not running
- upstream cs: ee43da63fc88
* Fri Feb  8 2013 dmuhamedagic@suse.com
- hb_report: fix false disk full errors
- upstream cs: afd858980b16
* Fri Feb  1 2013 dmuhamedagic@suse.com
- hb_report: exit early on disk full (FATE#313815)
- hb_report: create links instead of copying PE inputs
  (FATE#313815)
- drop LRM bits (bnc#800095)
- upstream cs: 54ec848c439e
* Sat Dec 15 2012 dmuhamedagic@suse.com
- stonith: external/libvirt: don't log if status succeeded
- stonith: if debug's not set, do not send debug messages
  to the logger (bnc#792124)
- hb_report: readd description fields to description.txt (SUSE)
- hb_report: do zypper ref before trying to get packages
- stonith: log status message at the debug level (bnc#792124)
- stonith: don't always log debug level messages (bnc#792124)
- stonith: external/vcenter: fix gethosts to produce list of
  nodes not vms (bnc#792704)
- Upstream version cs: 67224d37df80
* Mon Nov 19 2012 dmuhamedagic@suse.com
- this release has code to support Pacemaker v1.1.8
* Tue Oct 16 2012 dmuhamedagic@suse.com
- lrmd: set max-children depending on the number of processors
- lrmd: don't send parameters from ops back to crmd
- stonith: external/libvirt: support for reboot reset method
- stonith: external/virsh: update test for virsh output
- stonith: external/libvirt: add more search strings for domain
  start and stop
- hb_report: node's type got optional
- hb_report: make use of bash trace features
- hb_report: compatibility code for pacemaker v1.1.8
- build: link libstonith with stonith2 agents
- Upstream version cs: 02bdcf58f9a0 (glue-1.0.11)
* Tue Oct 16 2012 coolo@suse.com
- add explict buildrequire on libbz2-devel
* Mon Jul 16 2012 dmuhamedagic@suse.com
- set version to 1.0.10
- stonith: external/libvirt: add more search strings for domain
  start and stop
- Upstream version cs: 18489f275f75
* Mon Jul  9 2012 dmuhamedagic@suse.com
- clplumbing: cl_msg: revert max message size to 256Kb
- clplumbing: fix memleak for Gmain_timeout
- stonith: rhcs: avoid false error if parameter isn't set
- stonith: rhcs: pass the action via stdin too
- hb_report: add node time information
- hb_report: get corosync blackbox records if available
- hb_report: make sure that work directory gets removed
- hb_report: improve performance
- sbd: Debug mode added (bnc#753559, bnc#738295)
- sbd: Handle IO errors during slot allocation properly
  (bnc#753559)
- sbd: Explicitly inform the master process about IO problems on
  the child (bnc#738295)
- sbd: Make servant restart logic more robust and verbose
  (bnc#738295)
- sbd: Use async IO for disk reads to increase resilience against
  hung IO (bnc#738295)
- logd: add try-restart action to the logd init script
  (allows logd restart on upgrades)
- update regression tests
- Upstream version cs: fc64670fd789
* Thu Mar 22 2012 aspiers@suse.com
- add dependency on perl-TimeDate for hb_report (bnc#753562)
* Wed Mar 21 2012 dmuhamedagic@suse.com
- clplumbing: cl_msg: increase max message size to 512Kb
- clplumbing: cl_msg: increase compression threshold
- clplumbing: cl_msg: don't use traditional compression by default
- clplumbing: cl_msg: try compressing message before rejecting it as too big
- clplumbing: load bz2 compression module by default
- clplumbing: ipc: fix message size checks (bnc#752231)
- stonith: external/vcenter: return list of configured hosts on gethosts
- Upstream version cs: 6766d7061071
* Tue Mar 13 2012 dmuhamedagic@suse.com
- LRM: lrmd: add basic authentication (lf#2547)
- LRM: lrmd: if set, get max-children from the LRMD_MAX_CHILDREN environment var
- hb_report: add /etc/booth/booth.conf to the list of configurations (bnc#750049)
- Upstream version cs: 58686d5ae302
* Thu Feb  2 2012 dmuhamedagic@suse.com
- logd: remove runlevel 4 from the LSB info section in the logd
  init script (bnc#744120)
- Upstream version cs: d8c154589a16
* Mon Jan 16 2012 dmuhamedagic@suse.com
- stonith: adjust timeouts in the meta-data template (bnc#733337)
- Upstream version cs: 3efdcb8fc3af
* Mon Jan  9 2012 tserong@suse.com
- Only include glib.h in cl_uuid.h (don't directly use glib/gtypes.h)
* Mon Dec 12 2011 dmuhamedagic@suse.com
- hb_report: set back the default destination to current directory
- stonith: don't complain if rhcs plugins are not installed
- update release to 1.0.9
- Upstream version cs: ce78649ed7ea
* Fri Nov 25 2011 dmuhamedagic@suse.com
- LRM: lrmd: set op status to cancelled for running monitor operations
- stonith: add CRM stonith resource name to log messages
- stonith: external/ipmi: add the priv parameter (ipmitool -L)
- stonith: external/ipmi: add missing double quote
- ha_log: increase MAXENTITY size to accommodate long stonith strings
- Upstream version cs: 7583026c6ace
* Mon Nov  7 2011 dmuhamedagic@suse.com
- hb_report: improve destination directory handling (bnc#727295)
- Upstream version cs: 4b08977bece3
* Mon Oct 24 2011 dmuhamedagic@suse.com
- hb_report: add StrictHostKeyChecking=no to ssh options
- hb_report: better handling of corrupt logs
- hb_report: don't ssh to nodes which are unreachable
- Upstream version cs: 3b800f73ba59
* Thu Oct 20 2011 dmuhamedagic@suse.com
- stonith: load libplumb symbols manually (fixes ipmilan) (bnc#694243)
- hb_report: use absolute path when invoking slaves (bnc#662816)
- clplumbing: fix for cl_times() wraparound and subsequent crash
  with 32bit clock_t on 64bit systems (lf#2596)
- set release to 1.0.8
- Upstream version cs: 5ea7e344a633 (1.0.8)
* Mon Oct 10 2011 dmuhamedagic@suse.com
- Upstream version cs: f1d722d9cef1
* Mon Oct 10 2011 dmuhamedagic@suse.com
- LRM: cibsecret: add StrictHostKeyChecking=no to ssh options
- LRM: cibsecret: allow set if the parameter is already stashed
- LRM: cibsecret: better handling of ssh failures
- stonith: external/ipmi: add parameter to specify ipmitool location
* Tue Sep 20 2011 tserong@suse.com
- LRM: cibsecret: use crm_resource instead of crm (bnc#709758)
- LRM: cibsecret: allow management of local files only
- hb_report: run df(1) in background lest it blocks everything else
- hb_report: improve detecting ssh user
- LRM: lrmd: limit number of "stayed too long in operation list" log
  messages (bnc#636576)
- hb_report: don't invoke zypper with no packages
- hb_report: enforce removing destination directory with -Z
- LRM: cibsecret: keep pssh quiet
- LRM: cibsecret: refactor remote shell code
- hb_report: install debuginfo packages on platforms with zypper
  (bnc#641979)
- hb_report: put remote command on the line instead of using pipe
  (bnc#662816)
- stonith: external: reduce severity of messages on status failure
  (bnc#700102)
- LRM: lrmd: allow storing parameters in local files (lf#2415)
- hb_report: use sudo for remove collectors if connecting with user
  other than root
- hb_report: add .info files with the last byte pos for all logs
- lrmd: improve operation logging
- stonith: external/vcenter: new plugin
- stonith: hetzner: new external stonith plugin
- stonith: prevent symbol conflict with libcrypto (lf#2571, bnc#694243)
- stonith: external/ipmi: fix unique parameters' attributes
- sbd: Maximize scheduler and IO priority in the child processes
  (bnc#702907)
- sbd: Stop cleanly if watchdog cannot be opened, even if a worker
  thread has already started (bnc#680109)
- sbd: now supports 1, 2, or 3 devices (bnc#682634, fate#309375)
- sbd: worker processes indicate their device in ps
- sbd: Restart servants a maximum of ten times in succession
- sbd: Restart all dead servants once per hour (configurable via -t option).
- sbd: The restart interval can be shortened by sending SIGUSR1 to the sbd
  server process to restart everything at once.
- sbd: Improved handling of just two devices (three is recommended).
- sbd: Make failing to initalize the watchdog timeout annoying, but
  non-fatal.
- sbd: Abort if watchdog cannot be opened (bnc#680109)
- external/sbd: default to value from /etc/sysconfig/sbd if sbd_device
  is not set.
- external/sbd: support "crashdump" debug setting to cause a kernel
  crash instead of a reboot.
- Upstream version cs: 45b21f952b0f
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Add baselibs configuration
* Fri Mar 11 2011 coolo@novell.com
- prereq sysvinit services and don't start in !network runlevels
* Tue Feb  8 2011 tserong@novell.com
- LRM: raexecocf: list resource agents properly (bnc#664409)
- sbd: Fix timeout setting on archs where int != long (bnc#635690)
- stonith: external/libvirt: new plugin for libvirt virtualization
  technologies
- upstream version cs: 3e3d209f9217
* Mon Feb  7 2011 ro@suse.de
- update to 1.0.7
  - clplumbing: ipc: adjust socket buffers size when adjusting ipc queue length
  - logd: add a SIGHUP signal handler to timely close/open log files
  - logd: use buffered io with fflush and fsync
  - logd: reopen logfiles on inode change (logrotate)
  - clplumbing: cl_log: keep logfiles open, but default to non-buffered io (lf#2470)
  - clplumbing: cl_log: add new optional common syslog message prefix
  - stonith: use ST_DEVICEID for the short description in meta-data
  - stonith: external: interpret properly exit codes from external stonith
    plugins (bnc#630357)
  - stonith: external: avoid false out of memory error if a parameter isn't set (bnc#646205)
  - stonith: external: check if PATH already contains GLUE_SHARED_DIR
    (memory leak, lf#2484)
  - stonith(8): reduce the number of stonith plugin invocations (bnc#630357)
  - stonith(8): use cl_log for logging if invoked by stonithd (pcmk 1.1)
  - stonith: external/sbd: make sbd use realtime priority for IO (works only with CFQ)
  - stonith: cyclades: add the serial_port parameter to the meta-data
  - stonith: external/riloe: add support for http proxies
  - stonith: external/ipmi: provide opt param "passwd_method" to hide
    the ipmi password from config and logs
  - stonith: external/nut: support for the Network UPS Tools
  - stonith: external/rackpdu: remove displaced local command
  - stonith: rcd_serial: rename dtr|rts parameter to dtr_rts
  - configure: test for POSIX signals (fixes rcd_serial)
* Tue Nov 23 2010 coolo@novell.com
- build against libnet-devel on 11.4
* Thu Aug 12 2010 lmb@novell.com
- stonith: Reduce logging.
- stonith: Improve response times by avoiding unnecessary queries to
  plugins (bnc#630357)
- stonith: external: interpret properly exit codes from external stonith
  plugins (bnc#630357)
- Upstream version cs: a146a145a3e
* Wed Aug  4 2010 lmb@novell.com
- sbd: increase IO priority to improve behaviour under load; it will
  take precedence over all other IO (FATE#310113).
  This requires the sbd device to use the CFQ scheduler for full effect.
- Upstream version cs: fb42b94f6f05
* Fri Jul 16 2010 dmuhamedagic@novell.com
- fix a wrong function declaration
- Upstream version cs: 8286b46c91e3
* Fri Jul  9 2010 dmuhamedagic@novell.com
- set version to 1.0.6
- ha_logger: log strings longer than 1024
- lrmd: don't allow cancelled operations to get back to the repeating op
  list (lf#2417)
- lrmd: exclude stonith resources from child count (bnc#612387)
- lrmd,clientlib: asynchronous resource delete notification (lf#2439)
- stonith: add -V (version) to stonith
- stonith: add -E option to get the configuration from the environment
- stonith: ha_log: feed the message to stdout and not on command line
- stonith: external/sbd,xen0: fix wrong reference from ha_log to
  ha_log.sh (deb#585120)
- stonith: external/rackpdu: check the snmpset and snmpwalk exit codes
- hb_report: create cib.txt after sanitizing the CIB (lf#2415)
- doc: generate lrmadmin.8 from the help text
- upstream version: stable release 1.0.6 (cs: 1c54d2895647)
* Wed May 12 2010 lmb@novell.com
- clplumbing: don't unlink uninitialized socket paths (reported by
  valgrind)
- external/sbd: Make monitoring simpler and more resilient (bnc#600593)
- Upstream version cs: 1448deafdf79
* Mon May 10 2010 lmb@novell.com
- lrmd: really remove operation history on client unregister
- Upstream version cs: 6cf2e36df9f4
* Mon May 10 2010 lmb@novell.com
- hb_report: collect drbd configuration (lf#2411)
- sbd: Print a warning if latency exceeds threshold, so that
  administrators get a warning before the watchdog suicide is triggered
  (bnc#600593)
- Upstream version cs: 4038a0c5b3eb
* Mon Apr 26 2010 lmb@novell.com
- external/ssh: move to devel package as well.
* Mon Apr 26 2010 dmuhamedagic@novell.com
- clplumbing: add again uid/gid for processes for authentication
  (the new fields are at the end of the struct; the users of the
  new fields may require library version 2.1.0)
* Thu Apr 15 2010 dmuhamedagic@novell.com
- clplumbing: revert patch 81ad41d14f72 to preserve the ABI
- upstream version 1.0.5 (cs d044096fe060)
* Mon Apr 12 2010 dmuhamedagic@novell.com
- stonith: external/sbd: fix status operation
- stonith: new external/ippower9258 plugin
- hb_report: update event patterns for corosync
- clplumbing: fix memory leak in cl_msg/lrmd (lf#1841,2389)
- upstream version cs: faada7f3d069
* Mon Mar 29 2010 dmuhamedagic@novell.com
- stonith: external/ibmrsa-telnet: fix ha_log.sh invocation
- stonith: external/ibmrsa-telnet: fix expect regex
- stonith: external/ipmi: make reset work when the node is off
- lrmd: check if tables exist before free_str_table and prevent
  segfault (bnc#587887)
- upstream version cs: f32cdc9c63b7
* Sun Mar 21 2010 lmb@novell.com
- lrmd: fix possible null pointer dereference
- hb_report: don't create dot files if there are more than 20 PE files
- stonith: external/riloe: log error message on unrecognized power
  method
- clplumbing: Add identity info of the user on the other side of socket
- upstream version cs: 6750314917db
* Mon Mar 15 2010 dmuhamedagic@novell.com
- hb_report: make dot and png files for PE inputs (if there are
  not too many)
- hb_report: do not filter CIB/PE files by default (use -s to
  force filtering)
- hb_report: add -Z option to force destination directory cleanup
- upstream version cs 5e7284501da6
* Mon Mar  8 2010 lmb@novell.com
- Ensure logd is restarted on update.
* Wed Mar  3 2010 lmb@novell.com
- Move external/ssh back to main package.
* Wed Mar  3 2010 dmuhamedagic@novell.com
- move also external/ssh stonith plugin to the devel package
* Wed Mar  3 2010 dmuhamedagic@novell.com
- upstream version cs 24691b945b0c
- hb_report: allow for default destination
- hb_report: when creating cts reports get information from the log
- hb_report: new option -d to keep the directory
* Mon Mar  1 2010 lmb@novell.com
- Move null and ssh stonith plugins to devel package, since they should
  never be used in production.
* Mon Feb 22 2010 dmuhamedagic@novell.com
- upstream version cs eae640f444ad
- hb_report: don't give up early when creating backtraces (lf#2350)
- clplumbing: Fix erroneous "Stack hogger failed 0xffffffff" warnings
- lrmd: raise severity from debug to info for some log messages
- lrmd: on shutdown exit once all operations finished (lf#2340)
- lrmd: don't add the cancel option in flush to the running operations (bnc#578644)
* Thu Feb  4 2010 dmuhamedagic@novell.com
- new upstream 1.0.3 (forgotten version update in configure.ac)
* Thu Feb  4 2010 dmuhamedagic@novell.com
- upstream version 1.0.3
- lrmd: don't flush operations which don't belong to the requesting client (lf#2161)
* Wed Jan 27 2010 lmb@novell.com
- Conflicts with heartbeat legacy packages needed to be versioned
  properly.
* Fri Jan 22 2010 lmb@novell.com
- Move the disablement of fatal warnings to an RPM section where it
  actually has an effect.
* Wed Jan 20 2010 dmuhamedagic@novell.com
- disable fatal warnings for ia64, ppc, and ppc64
* Mon Jan 11 2010 lmb@novell.com
- Disable fatal warnings.
* Mon Jan 11 2010 dmuhamedagic@novell.com
- upstream version cs: b75bd738dc09
  + lrmd: lookup clients by name (LF 2161)
* Tue Dec 29 2009 dmuhamedagic@novell.com
- upstream version cs: ce57c3d4ecfc
  + stonith: meatclient: add -w option to wait until we can connect
- start logd by default
- add preun, postun scripts for init.d scripts maintenance
- replace Conflicts with Provides
* Mon Dec 28 2009 dmuhamedagic@novell.com
- add Conflicts to the .spec files
* Wed Dec 23 2009 dmuhamedagic@novell.com
- Upstream version glue-1.0.2-rc2a
  + stonith: external plugins log using ha_log.sh (LF 2294,1971)
  + stonith: external: log messages immediately on manage and status calls
  + stonith: external/dracmc-telnet: new stonith plugin for Dell
  +   Drac/MC Blade Enclosure and Cyclades terminal server
  + stonith: external/riloe: make sure that host is turned on after power
  +   off/on reset (LF 2282)
  + stonith: external/riloe: workaround for the iLO double close of RIBCL
  +   element (bnc#553340)
  + stonith: cyclades: fix for support for newer PM10 firmware (LF 1938)
  + stonith: add -m option to stonith(8) to display metadata
  + stonith: add support for RHCS fence agents
  + LRM: raexec: close the logd fd too when executing agents (LF 2267)
  + LRM: lrmd: fix return code on LSB class RA exec failure (LF 2194)
  + hb_report: add -V (version) option
  + hb_report: add support for corosync
  + hb_report: add -v option (debugging)
  + hb_report: log/events combining
    in case nodes are logging to their
    local syslog, hb_report will produce a combined log and event file
    (sorted by date)
* Tue Dec 22 2009 tserong@novell.com
- /usr/share/heartbeat replaced with /usr/share/cluster-glue
* Tue Dec 22 2009 tserong@novell.com
- Upstream version cs: 4858a290f062
* Thu Dec 10 2009 "lmb@novell.com"
- Upstream version cs: c19cff3f4bbb
* Tue Dec  8 2009 "lmb@novell.com"
- lrmd: restore reset scheduler for children (bnc#551971)
- hb_report: "glibc" version also reported to detect mismatched
  installs.
- stonith: external: log output if plugins (bnc#548699,bnc#553340)
- lrmd: log outcome of monitor once an hour
- lrmd: remove operation history on client unregister and flushing all
  operations (lf#2161)
- Upstream version cs: 04a26c0878d8
* Sun Nov  1 2009 "lmb@novell.com"
- stonith: sbd: fix definition of sector_size for s390x (bnc#542827).
- Upstream version cs: beb067082760
* Tue Sep 29 2009 "lmb@novell.com"
- stonith: external/ibmrsa-telnet: add support for later RSA cards
- hb_report: add man page hb_report.8
- stonith: wti_nps: add support for internet power switch model
  (bnc#539912)
- Upstream version cs: 0bf5e34337ee.
* Tue Sep 15 2009 "lmb@novell.com"
- Rename to SLE HA 11 naming scheme.
- stonith: wti_mpc: support for MIB versions 1 and 3.
- Upstream version cs: b09aae4eeea7.
* Thu Aug 27 2009 "lmb@novell.com"
- sbd: Nodename comparison should be case insensitive
  (bnc#534445)
- sbd: describe "dump" command in help (bnc#529575).
- sbd: Accept -h (bnc#529574).
- hb_report: extract important events from the logs, and report further
  state information.
- Upstream version cs: 74715a6a60e7.
* Fri Aug 21 2009 "lmb@novell.com"
- Add logd init scripts.
- Install sbd.
- Fix-up hb_report.
- Include apcmastersnmp stonith plugin (bnc#518689).
- Include bladehpi stonith plugin (bnc#510299).
* Thu Aug 13 2009 lmb@novell.com
- Added Conflicts: with old heartbeat package layout.
- Enable IPMI and hpi support.
* Tue Aug 11 2009 abeekhof@novell.com
- Upstream version cs: aa5b5e48df62
  + Med: hb_report: report on more packages and with more state.
  + The -E option to lrmadmin does not take an argument
  + Provide a default value for docdir and ensure it is expanded
  + Low: clplumbing: fix a potential resource leak in cl_random (bnc#525393).
  + Med: hb_report: Include dlm_tool debugging information if available.
  + hb_report: Include more possible error output.
  + Ensure hb_report is built/packaged
* Wed Jul 29 2009 abeekhof@novell.com
- Fix installation of stonith docs
- Initial import of cluster-glue project after being split off from Heartbeat
- Upstream version cs: 2e136fee6761
